@@ -191,6 +191,12 @@ static u_int8_t
 slack_inode_act(FS_INFO *fs, INUM_T inum, FS_INODE *fs_inode, int flags,
   char *ptr)
 {
+
+	if (verbose)
+		fprintf (logfp,
+		  "slack_inode_act: Processing meta data: %lu\n",
+		  (ULONG)inum);
+
 	flen = fs_inode->size;
 	if ((fs->ftype & FSMASK) == FATFS_TYPE) {
 		fs->file_walk(fs, fs_inode, 0, 0, 
@@ -288,7 +294,7 @@ int     main(int argc, char **argv)
 		}
 	
 		fs->inode_walk(fs, fs->first_inum, fs->last_inum, 
-		  (FS_FLAG_ALLOC | FS_FLAG_USED | FS_FLAG_LINK), 
+		  (FS_FLAG_ALLOC | FS_FLAG_USED | FS_FLAG_LINK | FS_FLAG_NOABORT), 
 		  slack_inode_act, (char *)0);
 	
 		exit(0);
