@@ -65,16 +65,16 @@ void    fs_read_block(FS_INFO *fs, FS_BUF *buf, int len, DADDR_T addr,
      */
 
 	if (len % fs->dev_bsize)
-		error("%s: Block Read Request with length (%d) not a multiple of %d", 
-		  myname, len, fs->dev_bsize);
+		error("%s: Block Read Request with length (%d) not a multiple of %d (%s)", 
+		  myname, len, fs->dev_bsize, comment);
 
     if (len > buf->size)
-		error("%s: Buffer length is too short for read (%d > %d)", 
-		  myname, len, buf->size);
+		error("%s: Buffer length is too short for read (%d > %d) (%s)", 
+		  myname, len, buf->size, comment);
 
 	if (addr > fs->last_block)
-		error("%s: Read Error (address is too large for image %lu)", 
-		  myname, (ULONG)addr);
+		error("%s: Read Error (address is too large for image %lu) (%s)", 
+		  myname, (ULONG)addr, comment);
 
     /*
      * Bummer: with the 32-bit file model, Solaris 7 read() won't go past 2GB
@@ -91,14 +91,17 @@ void    fs_read_block(FS_INFO *fs, FS_BUF *buf, int len, DADDR_T addr,
 
 #ifdef USE_PREAD
     if (pread(fs->fd, buf->data, len, offs) != len)
-		error("read block error (%u@%.0f): %m", len, (double) offs);
+		error("read block error (%u@%.0f): %m (%s)", len, (double) offs,
+		  comment);
 #else
     if (fs->seek_pos != offs) {
 		if (LSEEK(fs->fd, offs, SEEK_SET) != offs)
-			error("read block lseek error (%llu): %m", (ULLONG) offs);
+			error("read block lseek error (%llu): %m (%s)", 
+			  (ULLONG) offs, comment);
 	}
     if (read(fs->fd, buf->data, len) != len)
-		error("read block read error (%d@%llu): %m", len, (ULLONG) offs);
+		error("read block read error (%d@%llu): %m (%s)", 
+		  len, (ULLONG) offs, comment);
 #endif
     fs->seek_pos = offs + len;
     buf->used = len;
@@ -117,10 +120,12 @@ void    fs_read_random(FS_INFO *fs, char *buf, int len, OFF_T offs,
 		myname, (double) offs, len, comment);
 
     if (LSEEK(fs->fd, offs, SEEK_SET) != offs)
-		error("read random seek error: offset %llu: %m", (ULLONG) offs);
+		error("read random seek error: offset %llu: %m (%s)", 
+		  (ULLONG) offs, comment);
 
     if ((count = read(fs->fd, buf, len)) != len)
-		error("read random read error (%d@%llu): %m", len, (ULLONG) offs);
+		error("read random read error (%d@%llu): %m (%s)", 
+		  len, (ULLONG) offs, comment);
 
     fs->seek_pos = offs + len;
 }
