@@ -594,11 +594,15 @@ ntfs_data_walk(NTFS_INFO *ntfs, FS_DATA *fs_data,
 				/* If the address is too large then give an error unless
 				 * the no abort flag is set */
 				if (addr > fs->last_block) {
-					if (flags & FS_FLAG_NOABORT)
+					if (flags & FS_FLAG_NOABORT) {
+						fprintf (stderr, "Invalid address in run (too large): %lu",
+						  (ULONG)addr);
 						return;
-					else
+					}
+					else {
 						error ("Invalid address in run (too large): %lu",
 						  (ULONG)addr);
+					}
 				}
 
 				if ((flags & FS_FLAG_AONLY) == 0) {
